==> nextcloud-app-spreed-1%3A7.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/he.js <==
OC.L10N.register(
    "spreed",
    {
    "a conversation" : "דיון",
    "(Duration %s)" : "(משך %s)",
    "You attended a call with {user1}" : "הצטרפת לשיחה עם {user1}",
    "_%n guest_::_%n guests_" : ["אורח/ת 1","%n אורחים","%n אורחים","%n אורחים"],
    "You attended a call with {user1} and {user2}" : "השתתפת בשיחה עם {user1} ועם {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "השתתפת בשיחה עם {user1}, {user2} ועם {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "השתתפת בשיחה עם {user1}, {user2}, {user3} ועם {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "השתתפת בשיחה עם {user1}, {user2}, {user3}, {user4} ועם {user5}",
    "_%n other_::_%n others_" : ["מישהו נוסף","%n נוספים","%n נוספים","%n נוספים"],
    "{actor} invited you to {call}" : "הוזמנת אל {call} על ידי {actor}",
    "Talk" : "שיחה",
    "Guest" : "אורח/ת",
    "{actor} created the conversation" : "הדיון נוצר על ידי {actor}",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "השם של הדיון השתנה מ־„%1$s” ל־„%2$s” על ידי {actor}",
    "{user} sent you a private message" : "התקבלה הודעה פרטית מאת {user}",
    "{user} invited you to a private conversation" : "הוזמנת לדיון פרטי על ידי {user}",
    "Join call" : "הצטרפות לשיחה",
    "{user} invited you to a group conversation: {call}" : "הוזמנת על ידי {user} לדיון קבוצתי: {call}",
    "A group call has started in {call}" : "החלה שיחה קבוצתית תחת {call}",
    "TURN server URL" : "כתובת שרת TURN",
    "Validate SSL certificate" : "אימות אישור SSL",
    "STUN server URL" : "כתובת שרת STUN",
    "TURN server protocols" : "פרוטוקולים לשרתים מסוג TURN",
    "UDP and TCP" : "UDP ו־TCP",
    "UDP only" : "UDP בלבד",
    "TCP only" : "TCP בלבד",
    "[Unknown user name]" : "[שם המשתמש לא ידוע]",
    "Copy link" : "העתקת קישור",
    "Leave conversation" : "יציאה מהדיון",
    "Delete conversation" : "מחיקת דיון",
    "Remove from favorites" : "הסרה מהמועדפים",
    "Add to favorites" : "הוספה למועדפים",
    "moderator" : "מפקח/ת",
    "Demote from moderator" : "הורדה מדרגת פיקוח",
    "Promote to moderator" : "קידום לדרגת פיקוח",
    "Remove participant" : "הסרת משתתף",
    "Share link" : "שיתוף קישור",
    "Participants" : "משתתפים",
    "Name" : "שם",
    "Saved" : "נשמר",
    "Shared secret" : "סוד משותף",
    "STUN servers" : "שרתי STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "שרת STUN משמש לאיתור כתובת ה־IP הציבורית של המשתמשים מאחורי נתב.",
    "Join a conversation or start a new one" : "ניתן להצטרף לדיון או להתחיל באחד חדש.",
    "The password is wrong. Try again." : "הססמה שגויה. נא לנסות שוב.",
    "Password" : "ססמה",
    "Fullscreen (f)" : "מסך מלא (f)",
    "TURN server" : "שרת TURN",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "שרת ה־TURN משמש לתיווך התעבורה מהמשתמשים שנמצאים מאחורי חומת אש.",
    "Join conversations at any time, any where, on any device." : "ניתן להצטרף לדיון בכל עת, מכל מקום, בכל מכשיר.",
    "Android app" : "יישומון ל־Android",
    "iOS app" : "יישומון ל־iOS",
    "Delete server" : "מחיקת שרת",
    "Add new server" : "הוספת שרת חדש",
    "You deleted all STUN servers. As it is almost always needed, a default STUN server was added." : "מחקת את כל שרתי ה־STUN. כיוון ששרת זה נחוץ כמעט תמיד, נוסף שרת STUN כבררת מחדל.",
    "TURN server shared secret" : "סוד משותף לשרת TURN",
    "New public conversation" : "דיון ציבורי חדש",
    "New group conversation" : "דיון קבוצתי חדש",
    "New conversation …" : "דיון חדש…",
    "Chat" : "צ׳אט",
    "Exit fullscreen (f)" : "יציאה ממסך מלא (f)",
    "Set your name in the chat window so other participants can identify you better." : "ניתן להגדיר את שמך בחלון הצ׳אט כדי שמשתתפים אחרים יוכלו לזהות אותך בצורה נוחה יותר.",
    "Copy" : "העתקה",
    "Copied!" : "הועתק!",
    "Not supported!" : "אין תמיכה!",
    "Press ⌘-C to copy." : "להעתקה יש ללחוץ ‎⌘-C.",
    "Press Ctrl-C to copy." : "להעתקה יש ללחוץ Ctrl-C.",
    "Request password" : "בקשת ססמה",
    "Error requesting the password." : "בקשת הססמה נכשלה.",
    "Please enter the password for this call" : "נא להקליד את הססמה של השיחה הזאת",
    "Password required" : "נדרשת ססמה",
    "Cancel" : "ביטול",
    "Submit" : "שליחה",
    "Leave call" : "יציאה מהשיחה",
    "Start call" : "התחלת שיחה",
    "Change password" : "החלפת ססמה",
    "Set password" : "הגדרת ססמה",
    "Conversation name" : "שם דיון",
    "Rename" : "שינוי שם",
    "Conversation with {name}" : "דיון עם {name}",
    "Error occurred while setting password" : "אירעה שגיאה בעת הגדרת ססמה",
    "Link copied!" : "קישור הועתק!",
    "You" : "אני",
    "No messages yet, start the conversation!" : "אין הודעות עדיין, ניתן להתחיל בדיון!",
    "New message …" : "הודעה חדשה…",
    "Send" : "שליחה",
    "Today" : "היום",
    "Yesterday" : "מחר",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Error occurred while sending message" : "אירעה שגיאה בעת שליחת ההודעה",
    "Edit" : "עריכה",
    "No other people in this call" : "אין אנשים נוספים בשיחה הזאת",
    "Waiting for {participantName} to join the call …" : "בהמתנה להצטרפות לשיחה מצד {participantName}…",
    "Waiting for others to join the call …" : "בהמתנה לאחרים להצטרף לשיחה…",
    "You can invite others in the participant tab of the sidebar" : "ניתן להזמין אחרים בלשונית המשתתפים בסרגל הצד",
    "Share this link to invite others!" : "יש לשתף את הקישור הזה כדי להזמין אחרים!",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "ניתן להזמין אחרים דרך לשונית המשתפים בסרגל הצד או לשתף את הקישור הזה כדי להזמין אחרים!",
    "WebRTC is not supported in your browser :-/" : "בדפדפן שלך אין תמיכה ב־WebRTC :-/",
    "Please use a different browser like Firefox or Chrome" : "נא להשתמש בדפדפן אחר כגון Firefox או Chrome",
    "Waiting for camera and microphone permissions" : "בהמתנה להרשאות גישה למצלמה ולמיקרופון",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "נא להעניק לדפדפן שלך גישה להשתמש במצלמה ובמיקרופון שלך כדי להשתמש ביישומון הזה.",
    "This conversation has ended" : "הדיון הסתיים",
    "Disable video" : "השבתת וידאו",
    "Share screen" : "שיתוף המסך",
    "Show your screen" : "הצגת המסך שלך",
    "Stop screensharing" : "הפסקת שיתוף המסך",
    "Unmute audio (m)" : "ביטול השקת שמע (m)",
    "Mute audio (m)" : "השתקת שמע (m)",
    "No audio" : "אין שמע",
    "Enable video (v)" : "הפעלת וידאו (v)",
    "Disable video (v)" : "השבתת וידאו (v)",
    "No Camera" : "אין מצלמה",
    "Screensharing is not supported by your browser." : "בדפדפן שלך אין תמיכה בשיתוף מסך.",
    "Screensharing requires the page to be loaded through HTTPS." : "לטובת שיתוף מסך יש לטעון את העמוד דרך HTTPS.",
    "Screensharing options" : "אפשרויות שיתוף מסך",
    "Sharing your screen only works with Firefox version 52 or newer." : "שיתוף מסך עובד עם Firefox בגרסה 52 ומעלה.",
    "Screensharing extension is required to share your screen." : "נדרשת הרחבה לשיתוף המסך כדי לשתף את המסך.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "נא להשתמש בדפדפן אחר כגון Firefox או Chrome כדי לשתף את המסך שלך.",
    "An error occurred while starting screensharing." : "אירעה שגיאה בעת התחלת שיתוף המסך.",
    "Enable screensharing" : "הפעלת שיתוף מסך",
    "Add participant …" : "הוספת משתתף…",
    "Favorited" : "סומן כמועדף",
    "Close" : "סגירה",
    "Show screen" : "הצגת מסך",
    "Enable video" : "הפעלת וידאו",
    "Access to microphone & camera is only possible with HTTPS" : "גישה למיקרופון ולמצלמה אפשרית רק עם HTTPS",
    "Please move your setup to HTTPS" : "נא להעביר את התצורה שלך ל־HTTPS",
    "Access to microphone & camera was denied" : "הגישה למיקרופון ולמצלמה נדחתה",
    "WebRTC is not supported in your browser" : "בדפדפן שלך אין תמיכה ב־WebRTC",
    "Error while accessing microphone & camera" : "אירעה שגיאה בעת גישה למיקרופון ולמצלמה",
    "{participantName}'s screen" : "המסך של {participantName}",
    "Guest's screen" : "המסך של האורח/ת",
    "Your screen" : "המסך שלך",
    "%s invited you to a private conversation" : "הוזמנת לדיון פרטי על ידי %s",
    "%s invited you to a group conversation: %s" : "הוזמנת על ידי %s לדיון קבוצתי: %s",
    "%s invited you to a group conversation" : "הוזמנת לדיון קבוצתי על ידי %s",
    "{user} invited you to a group conversation" : "הוזמנת לדיון קבוצתי על ידי {user}",
    "A group call has started" : "החלה שיחה קבוצתית",
    "Video & audio-conferencing using WebRTC" : "דיון עם קול ותמונה באמצעות WebRTC",
    "This call is password-protected" : "שיחה זו מוגנת בססמה",
    "Signaling server" : "שרת איתות"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");

==> nextcloud-app-spreed-1%3A8.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/he.js <==
OC.L10N.register(
    "spreed",
    {
    "a conversation" : "דיון",
    "(Duration %s)" : "(משך %s)",
    "You attended a call with {user1}" : "הצטרפת לשיחה עם {user1}",
    "_%n guest_::_%n guests_" : ["אורח/ת 1","%n אורחים","%n אורחים","%n אורחים"],
    "You attended a call with {user1} and {user2}" : "השתתפת בשיחה עם {user1} ועם {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "השתתפת בשיחה עם {user1}, {user2} ועם {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "השתתפת בשיחה עם {user1}, {user2}, {user3} ועם {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "השתתפת בשיחה עם {user1}, {user2}, {user3}, {user4} ועם {user5}",
    "_%n other_::_%n others_" : ["מישהו נוסף","%n נוספים","%n נוספים","%n נוספים"],
    "{actor} invited you to {call}" : "הוזמנת אל {call} על ידי {actor}",
    "Talk" : "שיחה",
    "Guest" : "אורח/ת",
    "{actor} created the conversation" : "הדיון נוצר על ידי {actor}",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "השם של הדיון השתנה מ־„%1$s” ל־„%2$s” על ידי {actor}",
    "{user} sent you a private message" : "התקבלה הודעה פרטית מאת {user}",
    "{user} invited you to a private conversation" : "הוזמנת לדיון פרטי על ידי {user}",
    "Join call" : "הצטרפות לשיחה",
    "{user} invited you to a group conversation: {call}" : "הוזמנת על ידי {user} לדיון קבוצתי: {call}",
    "A group call has started in {call}" : "החלה שיחה קבוצתית תחת {call}",
    "Invalid date, date format must be YYYY-MM-DD" : "תאריך לא חוקי, תבנית התאריך חייבת להיות YYYY-MM-DD",
    "Request password" : "בקשת ססמה",
    "Error requesting the password." : "בקשת הססמה נכשלה.",
    "This conversation has ended" : "הדיון הסתיים",
    "None" : "אין",
    "User" : "משתמש",
    "Everyone" : "כולם",
    "Disabled" : "מושבת",
    "Users" : "משתמשים",
    "TURN server URL" : "כתובת שרת TURN",
    "Validate SSL certificate" : "אימות אישור SSL",
    "STUN server URL" : "כתובת שרת STUN",
    "TURN server protocols" : "פרוטוקולים לשרתים מסוג TURN",
    "UDP and TCP" : "UDP ו־TCP",
    "UDP only" : "UDP בלבד",
    "TCP only" : "TCP בלבד",
    "Copy link" : "העתקת קישור",
    "No other people in this call" : "אין אנשים נוספים בשיחה הזאת",
    "Waiting for others to join the call …" : "בהמתנה לאחרים להצטרף לשיחה…",
    "You can invite others in the participant tab of the sidebar" : "ניתן להזמין אחרים בלשונית המשתתפים בסרגל הצד",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "ניתן להזמין אחרים דרך לשונית המשתפים בסרגל הצד או לשתף את הקישור הזה כדי להזמין אחרים!",
    "Share this link to invite others!" : "יש לשתף את הקישור הזה כדי להזמין אחרים!",
    "Show your screen" : "הצגת המסך שלך",
    "Stop screensharing" : "הפסקת שיתוף המסך",
    "No audio" : "אין שמע",
    "Mute audio (m)" : "השתקת שמע (m)",
    "Unmute audio (m)" : "ביטול השקת שמע (m)",
    "Disable video (v)" : "השבתת וידאו (v)",
    "Enable video (v)" : "הפעלת וידאו (v)",
    "Screensharing options" : "אפשרויות שיתוף מסך",
    "Enable screensharing" : "הפעלת שיתוף מסך",
    "Screensharing requires the page to be loaded through HTTPS." : "לטובת שיתוף מסך יש לטעון את העמוד דרך HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "שיתוף מסך עובד עם Firefox בגרסה 52 ומעלה.",
    "Screensharing extension is required to share your screen." : "נדרשת הרחבה לשיתוף המסך כדי לשתף את המסך.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "נא להשתמש בדפדפן אחר כגון Firefox או Chrome כדי לשתף את המסך שלך.",
    "An error occurred while starting screensharing." : "אירעה שגיאה בעת התחלת שיתוף המסך.",
    "Your screen" : "המסך שלך",
    "Show screen" : "הצגת מסך",
    "Disable video" : "השבתת וידאו",
    "Enable video" : "הפעלת וידאו",
    "Favorite" : "סימון כמועדף",
    "Leave conversation" : "יציאה מהדיון",
    "Delete conversation" : "מחיקת דיון",
    "Remove from favorites" : "הסרה מהמועדפים",
    "Add to favorites" : "הוספה למועדפים",
    "Conversations" : "דיונים",
    "Contacts" : "אנשי קשר",
    "Groups" : "קבוצות",
    "Loading" : "בטעינה",
    "Error" : "שגיאה",
    "Password protect" : "הגנה בססמה",
    "Back" : "חזרה",
    "Close" : "סגירה",
    "Conversation name" : "שם דיון",
    "Reply" : "תגובה",
    "[Unknown user name]" : "[שם המשתמש לא ידוע]",
    "Today" : "היום",
    "Yesterday" : "מחר",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "moderator" : "מפקח/ת",
    "guest" : "אורח",
    "Demote from moderator" : "הורדה מדרגת פיקוח",
    "Promote to moderator" : "קידום לדרגת פיקוח",
    "Remove participant" : "הסרת משתתף",
    "No results" : "אין תוצאות",
    "Participants" : "משתתפים",
    "Rename conversation" : "שינוי שם הדיון",
    "Guests" : "אורחים",
    "Share link" : "שיתוף קישור",
    "Password protection" : "Password protection",
    "Enter a password" : "נא להקליד ססמה",
    "Chat" : "צ׳אט",
    "Edit" : "עריכה",
    "Leave call" : "יציאה מהשיחה",
    "Start call" : "התחלת שיחה",
    "Limit to groups" : "הגבלה לקבוצות",
    "Limit app usage to groups." : "להגביל את השימוש ביישומון לקבוצות.",
    "Save changes" : "שמירת שינויים",
    "Saved!" : "נשמר!",
    "Name" : "שם",
    "General settings" : "הגדרות כלליות",
    "Saved" : "נשמר",
    "Shared secret" : "סוד משותף",
    "STUN servers" : "שרתי STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "שרת STUN משמש לאיתור כתובת ה־IP הציבורית של המשתמשים מאחורי נתב.",
    "Join a conversation or start a new one" : "ניתן להצטרף לדיון או להתחיל באחד חדש.",
    "Please enter the password for this call" : "נא להקליד את הססמה של השיחה הזאת",
    "Password required" : "נדרשת ססמה",
    "Password" : "ססמה",
    "Cancel" : "ביטול",
    "Submit" : "שליחה",
    "Access to microphone & camera is only possible with HTTPS" : "גישה למיקרופון ולמצלמה אפשרית רק עם HTTPS",
    "Please move your setup to HTTPS" : "נא להעביר את התצורה שלך ל־HTTPS",
    "Access to microphone & camera was denied" : "הגישה למיקרופון ולמצלמה נדחתה",
    "WebRTC is not supported in your browser" : "בדפדפן שלך אין תמיכה ב־WebRTC",
    "Please use a different browser like Firefox or Chrome" : "נא להשתמש בדפדפן אחר כגון Firefox או Chrome",
    "Error while accessing microphone & camera" : "אירעה שגיאה בעת גישה למיקרופון ולמצלמה",
    "The password is wrong. Try again." : "הססמה שגויה. נא לנסות שוב.",
    "TURN server" : "שרת TURN",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "שרת ה־TURN משמש לתיווך התעבורה מהמשתמשים שנמצאים מאחורי חומת אש.",
    "Android app" : "יישומון ל־Android",
    "iOS app" : "יישומון ל־iOS",
    "Delete server" : "מחיקת שרת",
    "Add new server" : "הוספת שרת חדש",
    "You deleted all STUN servers. As it is almost always needed, a default STUN server was added." : "מחקת את כל שרתי ה־STUN. כיוון ששרת זה נחוץ כמעט תמיד, נוסף שרת STUN כבררת מחדל.",
    "TURN server shared secret" : "סוד משותף לשרת TURN",
    "Test server" : "שרת בדיקה",
    "New public conversation" : "דיון ציבורי חדש",
    "New group conversation" : "דיון קבוצתי חדש",
    "New conversation …" : "דיון חדש…",
    "Exit fullscreen (f)" : "יציאה ממסך מלא (f)",
    "Fullscreen (f)" : "מסך מלא (f)",
    "Set your name in the chat window so other participants can identify you better." : "ניתן להגדיר את שמך בחלון הצ׳אט כדי שמשתתפים אחרים יוכלו לזהות אותך בצורה נוחה יותר.",
    "Copy" : "העתקה",
    "Copied!" : "הועתק!",
    "Not supported!" : "אין תמיכה!",
    "Press ⌘-C to copy." : "להעתקה יש ללחוץ ‎⌘-C.",
    "Press Ctrl-C to copy." : "להעתקה יש ללחוץ Ctrl-C.",
    "Start a conversation" : "התחלת דיון",
    "Share" : "שיתוף",
    "Change password" : "החלפת ססמה",
    "Set password" : "הגדרת ססמה",
    "Rename" : "שינוי שם",
    "Conversation with {name}" : "דיון עם {name}",
    "Error occurred while setting password" : "אירעה שגיאה בעת הגדרת ססמה",
    "Link copied!" : "קישור הועתק!",
    "You" : "אני",
    "No messages yet, start the conversation!" : "אין הודעות עדיין, ניתן להתחיל בדיון!",
    "New message …" : "הודעה חדשה…",
    "Send" : "שליחה",
    "Error occurred while sending message" : "אירעה שגיאה בעת שליחת ההודעה",
    "Error while sharing" : "שגיאה בעת השיתוף",
    "Waiting for {participantName} to join the call …" : "בהמתנה להצטרפות לשיחה מצד {participantName}…",
    "WebRTC is not supported in your browser :-/" : "בדפדפן שלך אין תמיכה ב־WebRTC :-/",
    "Waiting for camera and microphone permissions" : "בהמתנה להרשאות גישה למצלמה ולמיקרופון",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "נא להעניק לדפדפן שלך גישה להשתמש במצלמה ובמיקרופון שלך כדי להשתמש ביישומון הזה.",
    "Mute audio" : "השתקת שמע",
    "Share screen" : "שיתוף המסך",
    "No Camera" : "אין מצלמה",
    "Screensharing is not supported by your browser." : "בדפדפן שלך אין תמיכה בשיתוף מסך.",
    "Add participant …" : "הוספת משתתף…",
    "Favorited" : "סומן כמועדף",
    "Always notify" : "להודיע תמיד",
    "Never notify" : "לא להודיע אף פעם",
    "{participantName}'s screen" : "המסך של {participantName}",
    "Guest's screen" : "המסך של האורח/ת",
    ", " : ", ",
    "%s invited you to a private conversation" : "הוזמנת לדיון פרטי על ידי %s",
    "%s invited you to a group conversation: %s" : "הוזמנת על ידי %s לדיון קבוצתי: %s",
    "%s invited you to a group conversation" : "הוזמנת לדיון קבוצתי על ידי %s",
    "{user} invited you to a group conversation" : "הוזמנת לדיון קבוצתי על ידי {user}",
    "A group call has started" : "החלה שיחה קבוצתית",
    "Video & audio-conferencing using WebRTC" : "דיון עם קול ותמונה באמצעות WebRTC",
    "This call is password-protected" : "שיחה זו מוגנת בססמה",
    "Signaling server" : "שרת איתות",
    "Join conversations at any time, any where, on any device." : "ניתן להצטרף לדיון בכל עת, מכל מקום, בכל מכשיר."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
